@@ -1226,11 +1226,24 @@ livi_window_class_init (LiviWindowClass *klass)
 
 
 static void
-add_controls_toggle (LiviWindow *self, GtkWidget *widget)
+on_pressed (LiviWindow *self, gint n_press, gdouble x, gdouble y, GtkGestureClick* gesture)
+{
+  g_assert (LIVI_IS_WINDOW (self));
+  g_assert (GTK_IS_GESTURE (gesture));
+
+  if (gtk_gesture_single_get_current_sequence (GTK_GESTURE_SINGLE (gesture)))
+    toggle_controls (self);
+  else
+    gtk_widget_activate_action (GTK_WIDGET (self), "win.toggle-play", NULL);
+}
+
+
+static void
+add_press_gesture (LiviWindow *self, GtkWidget *widget)
 {
   GtkGesture *gesture = gtk_gesture_click_new ();
 
-  g_signal_connect_swapped (gesture, "pressed", G_CALLBACK (toggle_controls), self);
+  g_signal_connect_swapped (gesture, "pressed", G_CALLBACK (on_pressed), self);
   gtk_event_controller_set_propagation_phase (GTK_EVENT_CONTROLLER (gesture), GTK_PHASE_TARGET);
   gtk_widget_add_controller (widget, GTK_EVENT_CONTROLLER (gesture));
 }
@@ -1269,8 +1282,9 @@ livi_window_init (LiviWindow *self)
     g_debug ("Using built in sink");
   }
 
-  add_controls_toggle (self, GTK_WIDGET (self->picture_video));
-  add_controls_toggle (self, GTK_WIDGET (self->revealer_center));
+  add_press_gesture (self, GTK_WIDGET (self->picture_video));
+  add_press_gesture (self, GTK_WIDGET (self->revealer_center));
+  add_press_gesture (self, GTK_WIDGET (self->img_center));
 
   arm_hide_controls_timer (self);
 
